#!/usr/bin/env python
#
# This script is run from a CI job on the project repository. It triggers
# a pipeline on the accompanying recipe repository
#
# Author: Paul McCarthy <pauldmccarthy@gmail.com>
#


import os
import sys

from fsl_ci_utils.conda      import get_recipe_url
from fsl_ci_utils.gitlab_api import (trigger_pipeline,
                                     wait_on_pipeline)


def main():

    server       = os.environ['CI_SERVER_URL']
    token        = os.environ['FSL_CI_API_TOKEN']
    project_path = os.environ['CI_PROJECT_PATH']
    project_repo = os.environ['CI_PROJECT_URL']
    project_ref  = os.environ['CI_COMMIT_REF_NAME']
    deploy       = os.environ.get('DEPLOY', None)
    recipe       = get_recipe_url(project_path, server)['path']

    if deploy is None:
        deploy = 'true' if (project_ref == 'master') else ''

    # These variables are passed to the
    # build-conda-package job on the
    # recipe repository. They control
    # how the package is built, and
    # whether the built package is
    # deployed to a conda channel.
    variables   = {
        'FSLCONDA_REVISION'   : project_ref,
        'FSLCONDA_REPOSITORY' : project_repo,
        'STAGING'             : 'true',
        'DEPLOY'              : deploy
    }

    # start the pipeline
    pipeline = trigger_pipeline(recipe, 'master', server, token, variables)
    pid      = pipeline['id']
    url      = pipeline['web_url']

    print(f'Triggered pipeline on {recipe} - see {url} for more details.')

    # We do not wait for the pipeline to finish because our
    # CI runner infrastructure can only run a limited number
    # of jobs, and having one job waiting on another uses
    # up a valuable job slot.


if __name__ == '__main__':
    main()
